@@ -70,6 +70,7 @@ class BatchProcessor:
     def load_module_by_filepath(self, module_name, module_filepath):
         module = None
         failure = None
+        spec = None
         try:
             spec = importlib.util.spec_from_file_location(module_name, module_filepath)
             spec.submodule_search_locations = list(__import__(__name__).__path__)
@@ -81,7 +82,7 @@ class BatchProcessor:
             # sys.modules[spec.name] = module
             spec.loader.exec_module(module)
         except Exception as e:
-            failure = f"Import of module '{module_name}'from file '{module_filepath}' had errors ({e})"
+            failure = f"Import of module '{module_name}'from file '{module_filepath}' had errors ({e}). (Spec was {pprint.pformat(spec)})"
             module = None
         return module, failure
 
@@ -399,15 +400,21 @@ class BatchProcessor:
         out["total"] = totals
         return out
 
+    def get_job_times(self):
+        raw = self.db.get_job_times()
+        return raw
+
     def get_status(self):
         # fmt: off
         status = {
-            "status": self.db.get_status_counts(),
-#            "last": self.db.get_jobs(limit=20),
-#            "last_failed": self.db.get_jobs(limit=20, status=["failed"]),
-#            "last_pending": self.db.get_jobs(limit=20, status=["pending"]),
-#            "last_in_progress": self.db.get_jobs(limit=20, status=["in-progress"]),
-            "counts": self.get_job_counts()}
+             "status": self.db.get_status_counts()
+#           , "last": self.db.get_jobs(limit=20),
+#           , "last_failed": self.db.get_jobs(limit=20, status=["failed"]),
+#           , "last_pending": self.db.get_jobs(limit=20, status=["pending"]),
+#           , "last_in_progress": self.db.get_jobs(limit=20, status=["in-progress"]),
+            , "counts": self.get_job_counts()
+            , "times": self.get_job_times()
+        }
         # fmt: on
         return status
 
