@@ -207,7 +207,7 @@ $$ language plpgsql;
         return self.dbc.query_none(
             """
                 update
-                    batch_log
+                    batch_log as b
                 set
                       last_started_at =
                         (case
@@ -301,7 +301,7 @@ $$ language plpgsql;
         self.dbc.query_none(
             """
                 update
-                    batch_log
+                    batch_log as b
                 set
                       last_started_at =
                         (case
@@ -339,7 +339,7 @@ $$ language plpgsql;
         return self.dbc.query_one(
             """
                 update
-                    batch_log
+                    batch_log as b
                 set
                     last_started_at =
                       (case
@@ -404,7 +404,7 @@ $$ language plpgsql;
         return self.dbc.query_one(
             """
                 update
-                    batch_log
+                    batch_log as b
                 set
                     last_started_at =
                       (case
@@ -550,6 +550,59 @@ $$ language plpgsql;
                 """
         )
 
+    def get_job_times(self, statuses=["done"]):
+        return self.dbc.query_many(
+            """
+                select
+                      'total' as type
+                    , count(*) as count
+                    , (min( extract('epoch' from last_finished_at - last_started_at)) *1000 )::int as min
+                    , (avg( extract('epoch' from last_finished_at - last_started_at))*1000 )::int as avg
+                    , (percentile_cont(0.5) within group (order by extract('epoch' from b2.last_finished_at - b2.last_started_at)::float )*1000 )::int as med
+                    , (max( extract('epoch' from last_finished_at - last_started_at))*1000 )::int as max
+                    , (min( ttl_seconds ))::int as min_ttl
+                    , (max( ttl_seconds ))::int as max_ttl
+                from
+                    batch_log as b2
+                where 
+                    status in %(statuses)s
+                and
+                    last_started_at is not null
+                and 
+                    last_finished_at  is not null
+                and
+                    last_finished_at > last_started_at
+
+union
+
+                select
+                      type
+                    , count(*) as count
+                    , (min( extract('epoch' from last_finished_at - last_started_at)) *1000 )::int as min
+                    , (avg( extract('epoch' from last_finished_at - last_started_at))*1000 )::int as avg
+                    , (percentile_cont(0.5) within group (order by extract('epoch' from b.last_finished_at - b.last_started_at)::float )*1000 )::int as med
+                    , (max( extract('epoch' from last_finished_at - last_started_at))*1000 )::int as max
+                    , (min( ttl_seconds ))::int as min_ttl
+                    , (max( ttl_seconds ))::int as max_ttl
+                from
+                    batch_log as b
+                where
+                    status in %(statuses)s
+                and
+                    last_started_at is not null
+                and 
+                    last_finished_at  is not null
+                and
+                    last_finished_at > last_started_at
+                group by
+                    type
+                order by
+                    type
+                ;
+                """,
+            {"statuses": (tuple(statuses),)},
+        )
+
     # Get batch items from batch log sorted by last active
     def get_jobs(self, id=None, priority=None, ttl_seconds=None, type=None, status=None, throttle_key=None, source=None, error=None, limit=1):
         return self.dbc.query_many(
